@@ -1,59 +1,61 @@
 package List::Objects::WithUtils;
 {
-  $List::Objects::WithUtils::VERSION = '1.012001';
+  $List::Objects::WithUtils::VERSION = '2.001001';
 }
 use Carp;
 use strictures 1;
 
-our @DefaultImport = qw/ array immarray hash /;
+our %ImportMap = (
+  array       => 'Array',
+  immarray    => 'Array::Immutable',
+  array_of    => 'Array::Typed',
+  immarray_of => 'Array::Immutable::Typed',
+  hash        => 'Hash',
+  immhash     => 'Hash::Immutable',
+  hash_of     => 'Hash::Typed',
+  immhash_of  => 'Hash::Immutable::Typed',
+);
+
+our @DefaultImport = keys %ImportMap;
 
 sub import {
   my ($class, @funcs) = @_;
 
   my $pkg;
   if (ref $funcs[0]) {
+    croak 'Expected a list of imports or a HASH but got '.$funcs[0]
+      unless ref $funcs[0] eq 'HASH';
     my %opts = %{ $funcs[0] };
     @funcs = @{ $opts{import} || [ 'all' ] };
     $pkg   = $opts{to} || caller;
   }
 
-  if (!@funcs) {
+  @funcs = @DefaultImport unless @funcs;
+  my %fmap = map {; 
+    lc( substr($_, 0, 1) eq ':' ? substr($_, 1) : $_ ) => 1
+  } @funcs;
+
+  if (defined $fmap{all}) {
+    @funcs = ( 
+      @DefaultImport,
+      'autobox'
+    )
+  } elsif (defined $fmap{functions} || defined $fmap{funcs}) {
+    # Legacy import tag
     @funcs = @DefaultImport
-  } elsif (grep {; lc $_ eq 'all' || lc $_ eq ':all' } @funcs) {
-    @funcs = ( @DefaultImport, 'autobox', 'array_of', 'hash_of' )
-  } elsif (grep {; lc $_ eq 'functions' || lc $_ eq ':functions' } @funcs) {
-    @funcs = ( @DefaultImport, 'array_of', 'hash_of' )
   }
 
   my @mods;
   for my $function (@funcs) {
-    if ($function eq 'array') {
-      push @mods, 'List::Objects::WithUtils::Array';
-      next
-    }
-    if ($function eq 'hash') {
-      push @mods, 'List::Objects::WithUtils::Hash'; 
-      next
-    }
-    if ($function eq 'immarray') {
-      push @mods, 'List::Objects::WithUtils::Array::Immutable';
-      next
-    }
-    if ($function eq 'array_of') {
-      push @mods, 'List::Objects::WithUtils::Array::Typed';
-      next
-    }
-    if ($function eq 'hash_of') {
-      push @mods, 'List::Objects::WithUtils::Hash::Typed';
-      next
-    }
     if ($function eq 'autobox') {
-      # Some unpleasantries required; autobox is weirdly scoped
       require List::Objects::WithUtils::Autobox;
       List::Objects::WithUtils::Autobox::import($class);
       next
     }
-
+    if (my $thismod = $ImportMap{$function}) {
+      push @mods, 'List::Objects::WithUtils::'.$thismod;
+      next
+    }
     carp "Unknown import parameter '$function'"
   }
 
@@ -66,7 +68,7 @@ sub import {
   }
 
   if (@failed) {
-    confess 'Failed to import ' . join ', ', @failed
+    croak 'Failed to import ' . join ', ', @failed
   }
 
   1
@@ -84,28 +86,23 @@ unless caller;
 
 =head1 NAME
 
-List::Objects::WithUtils - List objects with useful methods
+List::Objects::WithUtils - List objects, kitchen sink included
 
 =head1 SYNOPSIS
 
   ## A small sample; consult the description, below, for links to
   ## extended documentation
 
-  # Import selectively:
-  use List::Objects::WithUtils 'array';
-
-  # Import 'array()', 'immarray()', 'hash()' object constructors:
+  # Import all object constructor functions:
+  #   array immarray array_of immarray_of
+  #   hash immhash hash_of immhash_of
   use List::Objects::WithUtils;
 
-  # Import all functions:
-  use List::Objects::WithUtils ':functions';
-
   # Import all of the above plus autoboxing:
   use List::Objects::WithUtils ':all';
-  # Same, but via convenience shortcut:
+  # Same, but via the 'Lowu' shortcut:
   use Lowu;
 
-  # Some simple chained array operations, eventually returning a plain list
   # Most methods returning lists return new objects; chaining is easy:
   array(qw/ aa Ab bb Bc bc /)
     ->grep(sub { /^b/i })
@@ -115,13 +112,11 @@ List::Objects::WithUtils - List objects with useful methods
 
   # Useful utilities from other list modules are available:
   my $wanted = array(
-    +{ id => '200', user => 'bob' },
-    +{ id => '400', user => 'suzy' },
-    +{ id => '600', user => 'fred' },
+    +{ id => '400', user => 'bob' },
+    +{ id => '600', user => 'suzy' },
+    +{ id => '700', user => 'fred' },
   )->first(sub { $_->{id} > 500 });
 
-  my $sum = array( 1, 2, 3 )->reduce(sub { $_[0] + $_[1] });  # 6
-
   my $itr = array( 1 .. 7 )->natatime(3);
   while ( my @nextset = $itr->() ) {
     ...
@@ -152,14 +147,16 @@ List::Objects::WithUtils - List objects with useful methods
   $static->[0] = 'quux';    # dies
   push @$static, 'quux';    # dies
 
-  # Simple hash operations; construct a hash:
+  # Construct a hash:
   my $hash  = hash( foo => 'bar', snacks => 'cake' );
   
   # You can set multiple keys in one call:
   $hash->set( foobar => 'baz', pie => 'cherry' );
+
   # ... which is useful for merging in another (plain) hash:
   my %foo = ( pie => 'pumpkin', snacks => 'cheese' );
   $hash->set( %foo );
+
   # ... or another hash object:
   my $second = hash( pie => 'key lime' );
   $hash->set( $second->export );
@@ -174,6 +171,10 @@ List::Objects::WithUtils - List objects with useful methods
   # consisting of the retrieved key/value pairs:
   my $slice = $hash->sliced('foo', 'pie');
 
+  # Hashes can be inflated to objects:
+  my $obj = $hash->inflate;
+  $snacks = $obj->snacks;
+
   # Chained method examples; methods that return multiple values
   # typically return new array-type objects:
   my @match_keys = $hash->keys->grep(sub { m/foo/ })->all;
@@ -192,19 +193,15 @@ List::Objects::WithUtils - List objects with useful methods
     ...
   }
 
-  # Type-checking arrays:
+  # Type-checking arrays via Type::Tiny:
   use List::Objects::WithUtils 'array_of';
   use Types::Standard -all;
-  my $int_arr = array_of( Int, 1 .. 10 );
+  my $int_arr = array_of Int() => 1 .. 10;
 
   # Type-checking hashes:
   use List::Objects::WithUtils 'hash_of';
   use Types::Standard -all;
-  my $int_hash = hash_of( Int, foo => 1, bar => 2 );
-
-  # Hashes can be inflated to objects:
-  my $obj = $hash->inflate;
-  $snacks = $obj->snacks;
+  my $int_hash = hash_of Int() => (foo => 1, bar => 2);
 
   # Native list types can be autoboxed:
   use List::Objects::WithUtils 'autobox';
@@ -220,81 +217,58 @@ List::Objects::WithUtils - List objects with useful methods
 =head1 DESCRIPTION
 
 A set of roles and classes defining an object-oriented interface to Perl
-hashes and arrays with useful utility methods, junctions, and optional
-autoboxing.
+hashes and arrays with useful utility methods, junctions, type-checking
+ability, and optional autoboxing.
 
 Originally derived from L<Data::Perl>.
 
-B<array> is imported from L<List::Objects::WithUtils::Array> and creates a new
-ARRAY-type object. 
-Behavior is defined by L<List::Objects::WithUtils::Role::Array>; look
-there for documentation on available methods.
+=head2 Arrays
+
+B<array> (L<List::Objects::WithUtils::Array>) provides basic mutable
+ARRAY-type objects.  Behavior is defined by
+L<List::Objects::WithUtils::Role::Array>; look there for documentation on
+available methods.
 
 B<immarray> is imported from L<List::Objects::WithUtils::Array::Immutable> and
 operates much like an B<array>, except methods that mutate the list are not
-available and the backing ARRAY is marked read-only; using immutable arrays 
-promotes safer functional patterns.
+available; using immutable arrays promotes safer functional patterns.
 
-B<hash> is imported from L<List::Objects::WithUtils::Hash>; see  
+B<array_of> provides L<Type::Tiny>-compatible type-checking array objects
+that can coerce and check their values as they are added; see
+L<List::Objects::WithUtils::Array::Typed>.
+
+B<immarray_of> provides immutable type-checking arrays; see
+L<List::Objects::WithUtils::Array::Immutable::Typed>.
+
+=head2 Hashes
+
+B<hash> is the basic mutable HASH-type object imported from
+L<List::Objects::WithUtils::Hash>; see
 L<List::Objects::WithUtils::Role::Hash> for documentation.
 
+B<immhash> provides immutable (restricted) hashes; see
+L<List::Objects::WithUtils::Hash::Immutable>.
+
+B<hash_of> provides L<Type::Tiny>-compatible type-checking hash
+objects; see L<List::Objects::WithUtils::Hash::Typed>.
+
+B<immhash_of> provides immutable type-checking hashes; see
+L<List::Objects::WithUtils::Hash::Immutable::Typed>.
+
+=head2 Importing
+
+A bare import list (C<use List::Objects::WithUtils;>) will import all of the
+object constructor functions described above; they can also be selectively
+imported, e.g.:
+
+  use List::Objects::WithUtils 'array_of', 'hash_of';
+
 Importing B<autobox> lexically enables L<List::Objects::WithUtils::Autobox>,
 providing methods for native ARRAY and HASH types.
 
-A bare import list (C<use List::Objects::WithUtils;>) will import the
-C<array>, C<immarray>, and C<hash> functions.
-
-Importing B<array_of> gives you L<Type::Tiny>-compatible type-checking array
-objects; see L<List::Objects::WithUtils::Array::Typed>.
-
-Importing B<hash_of> gives you L<Type::Tiny>-compatible type-checking hash
-objects; see L<List::Objects::WithUtils::Hash::Typed>.
-
-Importing B<functions> or B<:functions> will import all of the above.
-
-Importing B<all> or B<:all> will import all of the above and additionally turn
-B<autobox> on, as will the shortcut C<use Lowu;> (as of 1.003).
-
-B<Why another object-oriented list module?>
-
-There are a fair few object-oriented approaches to lists on CPAN, none of
-which were quite what I needed. L<Data::Perl> comes the closest -- but is
-primarily targetting MooX::HandlesVia and could not guarantee a stable API at the
-time this was written (plus, I don't need the other data types).
-
-This module aims to provide a consistent, natural interface to hashes and
-arrays exclusively, with convenient access to common tools. The interface is
-expected to remain stable; methods may be added but are
-not expected to be removed (or experience incompatible interface changes, barring
-serious bugs).
-
-=head1 SEE ALSO
-
-L<List::Objects::WithUtils::Role::Array> for documentation on the basic set of
-C<array()> methods.
-
-L<List::Objects::WithUtils::Role::WithJunctions> for documentation on C<array()>
-junction-returning methods.
-
-L<List::Objects::WithUtils::Role::Hash> for documentation regarding C<hash()>
-methods.
-
-L<List::Objects::WithUtils::Array::Immutable> for more on C<immarray()>
-immutable arrays.
-
-L<List::Objects::WithUtils::Array::Typed> for more on C<array_of()>
-type-checking arrays.
-
-L<List::Objects::WithUtils::Hash::Typed> for more on C<hash_of()>
-type-checking hashes.
-
-L<List::Objects::WithUtils::Autobox> for details on autoboxing.
-
-The L<Lowu> module for a convenient importer shortcut.
-
-L<List::Objects::Types> for relevant L<Type::Tiny> types.
-
-L<MoopsX::ListObjects> for integration with L<Moops> class-building sugar.
+Importing B<all> or B<:all> will import all of the object constructors and
+additionally turn B<autobox> on; C<use Lowu;> is a shortcut for importing
+B<all>.
 
 =head2 Subclassing
 
@@ -321,7 +295,7 @@ For example, it's easy to create your own array class with new methods:
   package My::Array::Object;
   use Role::Tiny::With;
   with 'List::Objects::WithUtils::Role::Array',
-       'List::Objects::WithUtils::Role::WithJunctions';
+       'List::Objects::WithUtils::Role::Array::WithJunctions';
 
   # An easy way to add your own functional interface:
   use Exporter 'import';  our @EXPORT = 'my_array';
@@ -343,6 +317,40 @@ overrides C<array_type> to produce your preferred arrays:
 
   # ...
  
+=head1 SEE ALSO
+
+L<List::Objects::WithUtils::Role::Array> for documentation on the basic set of
+C<array()> methods.
+
+L<List::Objects::WithUtils::Role::Array::WithJunctions> for documentation on C<array()>
+junction-returning methods.
+
+L<List::Objects::WithUtils::Role::Hash> for documentation regarding C<hash()>
+methods.
+
+L<List::Objects::WithUtils::Array::Immutable> for more on C<immarray()>
+immutable arrays.
+
+L<List::Objects::WithUtils::Array::Typed> for more on C<array_of()>
+type-checking arrays.
+
+L<List::Objects::WithUtils::Array::Immutable::Typed> for more on
+C<immarray_of()> immutable type-checking arrays.
+
+L<List::Objects::WithUtils::Hash::Typed> for more on C<hash_of()>
+type-checking hashes.
+
+L<List::Objects::WithUtils::Hash::Immutable::Typed> for more on
+C<immhash_of()> immutable type-checking hashes.
+
+L<List::Objects::WithUtils::Autobox> for details on autoboxing.
+
+The L<Lowu> module for a convenient importer shortcut.
+
+L<List::Objects::Types> for relevant L<Type::Tiny> types.
+
+L<MoopsX::ListObjects> for integration with L<Moops> class-building sugar.
+
 =head1 AUTHOR
 
 Jon Portnoy <avenj@cobaltirc.org>
@@ -352,12 +360,13 @@ Licensed under the same terms as Perl.
 The original Array and Hash roles were derived from L<Data::Perl> by Matthew
 Phillips (CPAN: MATTP), haarg, and others.
 
-Immutable array objects were inspired by L<Const::Fast>.
+Immutable array objects were inspired by L<Const::Fast> by Leon Timmermans
+(CPAN: LEONT)
 
-Junctions are adapted from L<Perl6::Junction> by Carl Franks.
+Junctions are adapted from L<Perl6::Junction> by Carl Franks (CPAN: CFRANKS)
 
-Many of the useful type-checking bits were contributed by Toby Inkster (CPAN:
-TOBYINK).
+Most of the type-checking code and other useful additions were contributed by
+Toby Inkster (CPAN: TOBYINK)
 
 Much of this code simply wraps other widely-used modules, including:
 
