@@ -1,6 +1,6 @@
 package List::Objects::WithUtils::Array;
 {
-  $List::Objects::WithUtils::Array::VERSION = '1.012001';
+  $List::Objects::WithUtils::Array::VERSION = '2.001001';
 }
 use strictures 1;
 
@@ -8,7 +8,7 @@ require Role::Tiny;
 Role::Tiny->apply_roles_to_package( __PACKAGE__,
   qw/
     List::Objects::WithUtils::Role::Array
-    List::Objects::WithUtils::Role::WithJunctions
+    List::Objects::WithUtils::Role::Array::WithJunctions
    /
 );
 
@@ -35,7 +35,7 @@ List::Objects::WithUtils::Array - Array-type objects WithUtils
 See L<List::Objects::WithUtils::Role::Array> for a description of available
 methods.
 
-This class also consumes L<List::Objects::WithUtils::Role::WithJunctions>.
+This class also consumes L<List::Objects::WithUtils::Role::Array::WithJunctions>.
 
 =head2 array
 
